You can use the `Badge Builder </builder>`_ to help you create YAML files for
new badges.

This project is Free Software; you can find the `source
<https://github.com/fedora-infra/tahrir>`_ on GitHub.

You can report bugs and file issues with التحرير (Tahrir) on `the GitHub issues
tracker <https://github.com/fedora-infra/tahrir/issues>`_.
